﻿// Photoshopのテキストレイヤーに文字があるか検索しエイリアスを作成する
(function(){
    // PSDファイルがあるフォルダを指定する
    var folderObj = Folder.selectDialog("文字を検索するPSDファイルがあるフォルダを選択してください");
    if (!folderObj){ return; }  // キャンセルされた場合は何も処理しない
    // エイリアスを入れるフォルダを指定する
    var saveFolder = Folder.selectDialog("結果（エイリアス）を保存するフォルダを選択してください");
    if (!saveFolder){ return; }  // キャンセルされた場合は何も処理しない
    // 検索する文字列を入力
    var searchText = prompt("検索する文字列を入れてください", "mz");
    if (!searchText){ return; } // キャンセルされたら何もしない
    makeAliasList(folderObj);
    alert("検索が終了しました");
    // エイリアスを作成する関数
    function makeAliasList(folderObj){
        // PSDファイル一覧を取得する
        var fileList = folderObj.getFiles("*.psd");
        // ファイルの数だけ開いて文字列を検索する
        for(var i=0; i<fileList.length; i++){
            app.open(fileList[i]);
            var flag = findText(activeDocument, searchText);
            if (flag == true){
                // ファイル名が重複しないようにスラッシュをアンダーバーにしたファイル名を使う
                var filename = fileList[i].fsName.replace(new RegExp("/", "g"), "_");
                // エイリアスとなるファイルオブジェクトを作成する
                var aliasFileObj = new File(saveFolder+"/"+filename);
                // エイリアスを作成する
                var flag = aliasFileObj.createAlias(fileList[i]);
                if (flag == false){
                    $.writeln("失敗："+filename);
                    // もし、アラートダイアログを表示した方がいい場合は以下の行の//を消してください。
                    // alert("失敗："+filename);
                }
            }
            app.activeDocument.close(SaveOptions.DONOTSAVECHANGES);
        }
        // フォルダを含めた一覧を取得する
        fileList = folderObj.getFiles();
        for(var i=0; i<fileList.length; i++){
            // フォルダかどうか調べる
            if(fileList[i].getFiles){
                makeAliasList(fileList[i]);  // フォルダの場合は再帰呼び出し
            }
        }
        // レイヤー内を検索する関数
        function findText(layObj, searchText){
            for(var i=0; i<layObj.artLayers.length; i++){
                if(layObj.artLayers[i].kind == LayerKind.TEXT){
                    var text = layObj.artLayers[i].textItem.contents;
                    // 一致しているかどうか調べる
                    if (text.indexOf(searchText) > -1){
                        // 一致していたら以後の処理を中断して戻る
                        return true;
                    }
                }
            }
            // レイヤーセットの場合は自分自身の関数を呼び出して処理する
            for(var i=0; i<layObj.layerSets.length; i++){
                var flag = findText(layObj.layerSets[i], searchText);
                if (flag == true){ return true; }
            }
            return false;
        }
    }
})();
